# pydecs

PYthon code for point-like Defect Equilibria in Crystalline Solids

For details, see *** and following wiki-page:
<https://gitlab.com/tkog/pydecs/wikis/pydecs-(Main-page)>

This module is licensed under the Apache License, Version2.0, see LICENSE.txt.
